package com.muyu.server.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.domain.Connect;
import com.muyu.common.domain.DataName;
import com.muyu.server.service.DataRunNameService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @Author：yang
 * @Package：com.muyu.server.controller 级联
 * @Project：cloud-property
 * @name：DataRunNameController
 * @Date：2024/8/27 22:09
 */
@RestController
@RequestMapping("/dataRunName")
@Tag(name = "抽取数据名，数据表名",description = "级联")
@AllArgsConstructor
public class DataRunNameController {

    private DataRunNameService dataRunNameService;

    /**
     * 添加 数据库名，表名，结构
     */
    @PostMapping("/addDataTableName")
    @Operation(summary = "添加数据库名，表名，结构",description = "获取数据进行添加")
    public Result<String> addDataTableName(@RequestBody Connect connect){
        String s = dataRunNameService.addDataTableName(connect);
        return Result.success(s,"同步成功");
    }

    /**
     *  连接数据库获取当前所有的数据库名称
     * @return 所有数据库以及所有表的结果集
     */
    @PostMapping("/extractDataName")
    @Operation(summary = "获取数据库名",description = "返回所有数据库以及所有表的结果集")
    public Result<List<DataName>> getDatabase(){

        return Result.success(dataRunNameService.getDatabasesName());
    }

    /**
     *  连接数据库获取当前所有的数据库名称和所有字段
     * @return 所有数据库以及所有表的结果集
     */
    @PostMapping("/extractDataTableName")
    @Operation(summary = "获取数据库名",description = "返回所有数据库以及所有表的结果集")
    public Result<List<DataName>> getDataBaseTableName(){

        return Result.success(dataRunNameService.getDataBaseTableName());
    }
}
