package com.muyu.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.common.core.domain.Result;
import com.muyu.common.domain.Connect;
import com.muyu.common.domain.DataName;
import com.muyu.common.domain.TableFie;
import com.muyu.common.domain.TableNames;
import com.muyu.server.service.*;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * @Author：yang
 * @Package：com.muyu.server.service.impl
 * @Project：cloud-property
 * @name：DataRunNameImpl
 * @Date：2024/8/27 20:01
 */
@Service
@Log4j2
public class DataRunNameServiceImpl implements DataRunNameService {

    @Autowired
    private TableRunNameService tableRunNameService;
    @Autowired
    private DataNameService dataNameService;
    @Autowired
    private DataSourceService dataSourceService;
    @Autowired
    private TableFieldService tableFieldService;

    /**
     * 添加 数据库名，表名，结构
     */
    @Override
    public String addDataTableName(Connect connect) {

        //获取数据库名称
        DataName dataName1 = new DataName();
        dataName1.setName(connect.getDatabaseName());
        dataNameService.save(dataName1);

        //获取数据库表的名称
        List<TableNames> tableNames = tableRunNameService.extractTableName(connect.getDatabaseName());
        tableNames.forEach(tableName -> {
            log.info("数据库ID:{}",dataName1.getId());
            tableName.setDataId(dataName1.getId());
        });

        tableRunNameService.saveBatch(tableNames);
        if (CollectionUtils.isEmpty(tableNames))
        {
            return "数据库里不存在表";
        }
//        List<TableFie> tableFies = null;
//
        //遍历数据表名称
        for (TableNames tableName : tableNames) {

            log.info("数据库表ID:{}",tableName.getId());
            connect.setTableName(tableName.getName());
            List<TableFie> tableFies = dataSourceService.extractTableField(connect);
            tableFies.forEach(tableFy -> {
                tableFy.setTableId(tableName.getId());
            });
            if (CollectionUtils.isEmpty(tableFies))
            {
                return "数据库里表没有字段";
            }
            log.info("开始添加表结构与数据:{}",tableFies);
            tableFieldService.saveBatch(tableFies);
        }

        return "添加成功";
    }

    /**
     * 查询数据库名称 和 表名称联查
     * @return
     */
    @Override
    public List<DataName> getDatabasesName() {

        List<DataName> dataNames = dataNameService.extractDataName();
        dataNames.forEach(dataName -> {
            String name = dataName.getName();
            List<TableNames> tableNames = tableRunNameService.extractTableName(name);
            dataName.setTableNames(tableNames);
        });
        return dataNames;
    }

    /**
     *  连接数据库获取当前所有的数据库名称和所有字段
     * @return 所有数据库以及所有表的结果集
     */
    @Override
    public List<DataName> getDataBaseTableName() {

        List<DataName> dataNameList = dataNameService.list().stream()
                .map(DataName::dataNameBuild).toList();
        dataNameList.forEach(dataName -> {

            if (StringUtils.isNotBlank(String.valueOf(dataName.getId()))) {
                List<TableNames> tableNamesList = tableRunNameService.list(new LambdaQueryWrapper<TableNames>()
                                .eq(TableNames::getDataId, dataName.getId()))
                        .stream()
                        .map(TableNames::tableNamesBuild)
                        .toList();
                ArrayList<TableNames> namesArrayList = new ArrayList<>(tableNamesList);
                    dataName.setTableNames(namesArrayList);
                List<TableNames> tableNames1 = dataName.getTableNames();
                log.info("数据库表名称:{}",tableNames1);
                if (CollectionUtils.isEmpty(tableNames1)) {
                    return;
                }
                    tableNames1.forEach(tableName1 -> {
                        System.out.println(tableName1);
                        if (StringUtils.isNotBlank(String.valueOf(tableName1.getId()))) {
                            List<TableFie> tableFieList = tableFieldService.list(new LambdaQueryWrapper<TableFie>()
                                            .eq(TableFie::getTableId, tableName1.getId()))
                                    .stream()
                                    .map(TableFie::tableFieBuild).toList();
                            System.out.println(tableFieList);
                            ArrayList<TableFie> fieArrayList = new ArrayList<>(tableFieList);
                            tableName1.setTableFie(fieArrayList);
                        }
                    });

            }
        });
        return dataNameList;

    }
}
